==> eph_0.3.0.tar.gz: eph/R/eph.R <==
#' \code{eph} package
#'
#' Caja de Herramientas para el procesamiento de la Encuesta Permanente de Hogares
#'
#' See the README on
#' \href{https://github.com/pablinte/eph/blob/master/README.md}{Github}
#'
#' @docType package
#' @name eph
NULL

## quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1") utils::globalVariables(c(".",
                                                       "ANO4",
                                                       "CBA",
                                                       "CBT",
                                                       "CH04",
                                                       "CH06",
                                                       "CODUSU",
                                                       "COMPONENTE",
                                                       "ESTADO",
                                                       "Freq",
                                                       "NRO_HOGAR",
                                                       "PONDIH",
                                                       "TRIMESTRE",
                                                       "Trimestre",
                                                       "Var2",
                                                       "adequi",
                                                       "adequi_hogar",
                                                       "adulto_equivalente",
                                                       "anio",
                                                       "cba",
                                                       "cbt",
                                                       "con_controles",
                                                       "consistencia",
                                                       "ice",
                                                       "link",
                                                       "mes",
                                                       "n",
                                                       "periodo",
                                                       "situacion",
                                                       "put_labels_eph",
                                                       "sin_controles",
                                                       "microdata",
                                                       "error",
                                                       "filter_col",
                                                       "error_message",
                                                       ".data",
                                                       "Periodo",
                                                       "vars",
                                                       "CNO",
                                                       "digit",
                                                       "value",
                                                       "label",
                                                       "PP04D_COD",
                                                       "CLASIF_CNO",
                                                       "DIGIT12",
                                                       "DIGIT3",
                                                       "DIGIT4",
                                                       "DIGIT5",
                                                       "centroides_aglomerados"))

==> eph_0.4.0.tar.gz: eph/R/eph.R <==
#' \code{eph} package
#'
#' Caja de Herramientas para el procesamiento de la Encuesta Permanente de Hogares
#'
#' See the README on
#' \href{https://github.com/pablinte/eph/blob/master/README.md}{Github}
#'
#' @docType package
#' @name eph
NULL

## quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1") utils::globalVariables(c(".",
                                                       "ANO4",
                                                       "CBA",
                                                       "CBT",
                                                       "CH04",
                                                       "CH06",
                                                       "CODUSU",
                                                       "COMPONENTE",
                                                       "ESTADO",
                                                       "Freq",
                                                       "NRO_HOGAR",
                                                       "PONDIH",
                                                       "TRIMESTRE",
                                                       "Trimestre",
                                                       "Var2",
                                                       "adequi",
                                                       "adequi_hogar",
                                                       "adulto_equivalente",
                                                       "anio",
                                                       "cba",
                                                       "cbt",
                                                       "con_controles",
                                                       "consistencia",
                                                       "ice",
                                                       "link",
                                                       "mes",
                                                       "n",
                                                       "periodo",
                                                       "situacion",
                                                       "put_labels_eph",
                                                       "sin_controles",
                                                       "microdata",
                                                       "error",
                                                       "filter_col",
                                                       "error_message",
                                                       ".data",
                                                       "Periodo",
                                                       "vars",
                                                       "CNO",
                                                       "digit",
                                                       "value",
                                                       "label",
                                                       "PP04D_COD",
                                                       "CLASIF_CNO",
                                                       "DIGIT12",
                                                       "DIGIT3",
                                                       "DIGIT4",
                                                       "DIGIT5",
                                                       "centroides_aglomerados",
                                                       "PP04B_CAES",
                                                       "PP04B_COD",
                                                       "caes"))
